﻿//=======================================================================================
//
//  Purpose: Hold the information for a generic electrical component.
//
//
//  Copyright (C) 2011 Mark Stevens
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software") to use
//  the Software in a non-commercial environment subject to the following conditions:
//
//  1.  The above copyright notice and this permission notice shall be included in
//      all copies or substantial portions of the Software.
//  2.  The original author shall be acknowledged in any software and documentation
//      including (but not restricted to) books, articles and online posts.
//
//  Use in a commercial environment is subject to the written consent of the author
//  and/or copyright holder.
//
//  The Software, documentation, instructions for use and associated materials
//  are provided "as is" without warranty of any kind express or implied.  The
//  author and copyright holders shall ihn no way be held liable for any claim
//  or damages arising as a result of the use of the software and/or documentation.
//
//=======================================================================================
using System.ComponentModel;

namespace NE555Calculator
{
    /// <summary>
    /// Hold the name and value for a component.
    /// </summary>
    public class Component : INotifyPropertyChanged
    {
        /// <summary>
        /// Name of the component.
        /// </summary>
        private string _name;
        public string Name
        {
            get { return (_name); }
            set
            {
                _name = value;
                RaisePropertyChanged("Name");
            }
        }

        /// <summary>
        /// Value of the component.
        /// </summary>
        private double _value;
        public double Value
        {
            get { return (_value); }
            set
            {
                _value = value;
                RaisePropertyChanged("Value");
            }
        }

        #region Constructor(s)

        /// <summary>
        /// Create a new component.
        /// </summary>
        /// <remarks>
        /// Note that the value has no units associated with it.
        /// </remarks>
        /// <param name="name">Display name for the component</param>
        /// <param name="value">Value for the component</param>
        public Component(string name, double value)
        {
            Name = name;
            Value = value;
        }

        /// <summary>
        /// Default constuctor.
        /// </summary>
        private Component()
        {
            Name = null;
            Value = 0;
        }

        #endregion

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion

        #region Methods

        /// <summary>
        /// Notify any subscribers that a property has changed.
        /// </summary>
        /// <param name="properties">List of name of properties which may have changed.</param>
        private void RaisePropertyChanged(params string[] properties)
        {
            if ((properties != null) && (PropertyChanged != null))
            {
                foreach (string p in properties)
                {
                    PropertyChanged(this, new PropertyChangedEventArgs(p));
                }
            }
        }

        #endregion
    }
}
